@@ -17,42 +17,18 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} har arkiverat tavlan {before}",
     "You have unarchived the board {board}" : "Du har avarkiverat tavlan {board}",
     "{user} has unarchived the board {before}" : "{user} har avarkiverat tavlan {before}",
-    "You have created a new stack {stack} on board {board}" : "Du har skapat en ny stapel {stack} på on tavlan {board}",
-    "{user} has created a new stack {stack} on board {board}" : "{user} har skapat en ny stapel {stack} på tavlan {board}",
-    "You have renamed stack {before} to {stack} on board {board}" : "Du har bytt namn på stapel {before} till {stack} på tavlan {board}",
-    "{user} has renamed stack {before} to {stack} on board {board}" : "{user} har bytt namn på stapel {before} till {stack} på tavlan {board}",
-    "You have deleted stack {stack} on board {board}" : "Du har raderat stapel {stack} på tavlan {board}",
-    "{user} has deleted stack {stack} on board {board}" : "{user} har raderat stapel {stack} på tavlan {board}",
-    "You have created card {card} in stack {stack} on board {board}" : "Du har skapat kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has created card {card} in stack {stack} on board {board}" : "{user} har skapat kortet {card} i stapel {stack} på tavlan {board}",
-    "You have deleted card {card} in stack {stack} on board {board}" : "Du har raderat kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has deleted card {card} in stack {stack} on board {board}" : "{user} har raderat kortet {card} i stapel {stack} på tavlan {board}",
     "You have renamed the card {before} to {card}" : "Du har bytt namn på kortet {before} till {card}",
     "{user} has renamed the card {before} to {card}" : "{user} har bytt namn på kortet {before} till {card}",
-    "You have added a description to card {card} in stack {stack} on board {board}" : "Du har lagt till en beskrivning till kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has added a description to card {card} in stack {stack} on board {board}" : "{user} har lagt till en beskrivning till kortet {card} i stapel {stack} på tavlan {board}",
-    "You have updated the description of card {card} in stack {stack} on board {board}" : "Du har uppdaterat beskrivningen för kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has updated the description of the card {card} in stack {stack} on board {board}" : "{user} har uppdaterat beskrivningen för kortet {card} i stapel {stack} på tavlan {board}",
-    "You have archived card {card} in stack {stack} on board {board}" : "Du har arkiverat kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has archived card {card} in stack {stack} on board {board}" : "{user} har arkiverat kortet {card} i stapel {stack} på tavlan {board}",
-    "You have unarchived card {card} in stack {stack} on board {board}" : "Du har avarkiverat kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has unarchived card {card} in stack {stack} on board {board}" : "{user} har avarkiverat kortet {card} i stapel {stack} på tavlan {board}",
     "You have removed the due date of card {card}" : "Du har tagit bort förfallodatum för kortet {card}",
     "{user} has removed the due date of card {card}" : "{user} tagit bort förfallodatum för kortet {card}",
     "You have set the due date of card {card} to {after}" : "Du har satt förfallodatum för kortet {card} till {after}",
     "{user} has set the due date of card {card} to {after}" : "{user} har satt förfallodatum för kortet {card} till {after}",
     "You have updated the due date of card {card} to {after}" : "Du har uppdaterat förfallodatum för kortet {card} till {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} har uppdaterat förfallodatum för kortet {card} till {after}",
-    "You have added the tag {label} to card {card} in stack {stack} on board {board}" : "Du har lagt till taggen {label} till kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has added the tag {label} to card {card} in stack {stack} on board {board}" : "{user} har lagt till taggen {label} till kortet {card} i stapel {stack} på tavlan {board}",
-    "You have removed the tag {label} from card {card} in stack {stack} on board {board}" : "Du har raderat taggen {label} från kortet {card} i stapel {stack} på tavlan {board}",
-    "{user} has removed the tag {label} from card {card} in stack {stack} on board {board}" : "{user} har raderat taggen {label} från kortet {card} i stapel {stack} på tavlan {board}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Du har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "Du har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
-    "You have moved the card {card} from stack {stackBefore} to {stack}" : "Du har flyttat kortet {card} från stapel {stackBefore} till {stack}",
-    "{user} has moved the card {card} from stack {stackBefore} to {stack}" : "{user} har flyttat kortet {card} från stapel {stackBefore} till {stack}",
     "You have added the attachment {attachment} to card {card}" : "Du har lagt till bilagan {attachment} till kortet {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} har lagt till bilagan {attachment} till kortet {card}",
     "You have updated the attachment {attachment} on card {card}" : "Du har uppdaterat bilagan {attachment} på kortet {card}",
@@ -147,7 +123,6 @@ OC.L10N.register(
     "Can share" : "Kan dela",
     "Can manage" : "Kan hanter",
     "Delete" : "Radera",
-    "Add a new stack" : "Lägg till en ny stapel",
     "Delete list" : "Radera lista",
     "Add card" : "Lägg till kort",
     "Add a new card" : "Lägg till ett nytt kort",
@@ -170,9 +145,9 @@ OC.L10N.register(
     "(Unsaved)" : "(Inte sparad)",
     "(Saving…)" : "(Sparar…)",
     "Formatting help" : "Formatteringshjälp",
-    "Add Attachment" : "Lägg till bilaga",
     "Edit description" : "Ändra beskrivning",
     "View description" : "Visa beskrivning",
+    "Add Attachment" : "Lägg till bilaga",
     "Attachments" : "Bilagor",
     "Comments" : "Kommentarer",
     "Choose attachment" : "Välj bilaga",
@@ -196,16 +171,19 @@ OC.L10N.register(
     "Move card" : "Flytta kort",
     "Card details" : "Kortdetaljer",
     "Move card to another board" : "Flytta kort till en annan tavla",
-    "Select a stack" : "Välj en stapel",
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
     "Shared with you" : "Delad med dig",
     "Limit deck usage of groups" : "Begränsa användningen av grupper",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
-    "Settings" : "Inställningar",
     "New board title" : "Ny titel för tavla",
     "Edit board" : "Ändra tavla",
+    "Clone board " : "Kopiera tavla",
+    "Unarchive board " : "Ta bort tavlan ur arkivet",
+    "Archive board " : "Arkivera tavla",
+    "Delete board " : "Radera tavla",
     "Board details" : "Taveldetaljer",
+    "Board {0} deleted" : "Tavla {0} raderad",
     "An error occurred" : "Ett fel uppstod",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
     "Delete the board?" : "Radera tavlan?",
