@@ -24,6 +24,8 @@ OC.L10N.register(
     "Cancel" : "取消",
     "File already exists" : "檔案已存在",
     "Add new list" : "新增清單",
+    "Next 7 days" : "接下來 7 天",
+    "Next 30 days" : "接下來 30 天",
     "Details" : "詳細資料",
     "Sharing" : "分享",
     "Tags" : "標籤",
@@ -56,7 +58,6 @@ OC.L10N.register(
     "Delete card" : "刪除作業",
     "Move card" : "移動卡片",
     "Shared with you" : "與您分享",
-    "Settings" : "設定",
     "Edit board" : "編輯專案",
     "An error occurred" : "發生錯誤",
     "Link to a board" : "連結到佈告欄",
